@@ -5,9 +5,11 @@ import sys
 import click
 
 from r2k.cli import cli_utils, logger
-from r2k.config import config
+from r2k.config import Config
 from r2k.constants import Parser
 
+from .prompts import Prompt
+
 
 @click.command("init")
 @cli_utils.config_path_option(exists=False)
@@ -18,21 +20,19 @@ def config_init(path: str, force: bool) -> None:
     validate_config_overwrite(path, force)
 
     new_config = get_new_config()
-    config.reset(path=path, new_config=new_config)
+    new_config.save(path)
     logger.info("Successfully set the configuration!")
 
 
-def get_new_config() -> dict:
+def get_new_config() -> Config:
     """Ask the user to fill in all the necessary information, and return the resulting dict"""
-    send_from = logger.prompt("Please provide your gmail email address")
-    password = logger.prompt("Please provide your gmail app password", hide_input=True)
-    kindle_address = logger.prompt("Please provide your free kindle address (e.g. my_kindle@kindle.com)")
-    parser = logger.prompt(
-        "Please choose the parser you're going to use",
-        default=Parser.MERCURY,
-        type=click.Choice(Parser.SUPPORTED_PARSERS),
+    send_from = Prompt.get("send_from")
+    password = Prompt.get("password")
+    kindle_address = Prompt.get("kindle_address")
+    parser = Prompt.get("parser")
+    return Config(
+        feeds={}, send_from=send_from, kindle_address=kindle_address, password=password, parser=Parser(parser)
     )
-    return {"send_from": send_from, "kindle_address": kindle_address, "password": password, "parser": parser}
 
 
 def validate_config_overwrite(path: str, force: bool) -> None:
